@@ -12,13 +12,13 @@ def export_to_csv(nodes, output_dir):
     )
     print(edges)
     with open(edges_path, "w", newline="") as out:
-        csv_out = csv.writer(out)
+        csv_out = csv.writer(out, delimiter='\t')
         csv_out.writerow(["origin", "target"])
         for origin, target in edges:
             csv_out.writerow([origin, target])
 
     with open(nodes_path, "w", newline="") as out:
-        csv_out = csv.writer(out)
+        csv_out = csv.writer(out, delimiter='\t')
         csv_out.writerow(nodes[0].keys())
         for node in nodes:
             csv_out.writerow(node.values())
